@@ -26,6 +26,8 @@ CONFIG_DIR = user_data_dir(appname, appauthor)
 #os.makedirs(CONFIG_DIR, exist_ok = True)
 #%% general setup
 
+DATATABLE_COLUMN_NAME = 'time'
+DATATABLE_INDEX_NAME  = 'region'
 
 REQUIRED_META_FIELDS = {'entity',
                         'scenario',
@@ -90,7 +92,12 @@ else:
     # from .settings.personal import CRUNCHER, PATH_TO_DATASHELF, DB_READ_ONLY, DEBUG, AUTOLOAD_SOURCES
     
     #importng CRUNCHER, PATH_TO_DATASHELF, DB_READ_ONLY, DEBUG, AUTOLOAD_SOURCES
-    exec(open(os.path.join(CONFIG_DIR, 'personal.py')).read())
+    try:
+        config_file = os.path.join(CONFIG_DIR, 'personal.py')
+        exec(open(config_file).read())
+    except:
+        raise(Exception(f'Error in config file: {config_file}. Please correct'))
+        
     TEST_ENV = False
 
 
