@@ -22,7 +22,8 @@ tt = time.time()
 #%% Pint unit handling
 gases = {"CO2eq":"carbon_dioxide_equivalent",
          "CO2e" : "CO2eq",
-         "NO2" : "NO2"}
+         "NO2" : "NO2",
+         'PM25' : 'PM25'}
 
 from openscm_units import unit_registry as ur
 
@@ -74,7 +75,14 @@ LOG['tableIDs'] = list()
 
 ur.add_context(c)
 
-
+def is_known_entity(variable):
+    entity_matches = list()
+    for entity in naming_convention.entities:
+        if variable.startswith(entity):
+            return True
+    
+    return False
+    
 def _split_variable(metaDict):
     """
     Split variable into a known entity (see naming_converntion.py) and a 
@@ -105,8 +113,8 @@ def _split_variable(metaDict):
         if config.DEBUG:
             print(f'Warning: Entity could not be derived from {metaDict["variable"]}')
             
-            # exit here
-            return metaDict
+        # exit here
+        return metaDict
         
         
     #derive or check category
@@ -182,7 +190,7 @@ def _validate_unit(table):
         return False
 
 def generate_table_file_name(ID):
-    #ID_for_filename = _fix_filename(ID) 
+    ID_for_filename = _fix_filename(ID) 
     ID_for_filename = ID.replace('|','-').replace('/','-')
     return ID_for_filename + '.csv'
 
@@ -190,7 +198,7 @@ def _createDatabaseID(metaDict):
     ID =config.ID_SEPARATOR.join(
         [metaDict[key] for key in config.ID_FIELDS]
         )
-    ID = _fix_filename(ID)
+    # ID = _fix_filename(ID)
     return ID
 
 def csv_writer(filename, 
