@@ -78,8 +78,7 @@ def unique(table, field=None):
         print(unique_data)
         
         
-
-    #%%
+#%%
     
         
 class Database():
@@ -234,7 +233,6 @@ class Database():
         Input: tableID
         """
         self.inventory.drop(tableID, inplace=True)
-#        self.gitManager.updatedRepos.add('main')
     
     def findc(self, **kwargs):
         """
@@ -348,14 +346,16 @@ class Database():
     def _get_source_path(self, sourceID):
         return  os.path.join(config.PATH_TO_DATASHELF, 'database', sourceID)
     
-    def getTable(self, ID, load_raw=False):
+    def getTable(self, ID, native_regions=False):
         """
         Method to load the datatable for the given tableID.
         
         Input
         -----
         tableID : str
-        
+        native_regions : bool, optional
+            Load native region defintions if available. The default is False.
+
         Returns
         table : Datatable
         """
@@ -367,8 +367,9 @@ class Database():
             # load table from database
             
             filePath = self._getTableFilePath(ID)
-            table = read_csv(filePath,load_raw)
-            table = table[table.index.notnull()]
+            
+            table = read_csv(filePath,native_regions)
+            #table = table[table.index.notnull()]
             return table
         
         elif os.path.exists('data'):
@@ -376,8 +377,8 @@ class Database():
             filePath = os.path.join('data', fileName)
             
             if os.path.exists(filePath):
-               table = read_csv(filePath,load_raw)
-               table = table[table.index.notnull()]
+               table = read_csv(filePath,native_regions)
+               #table = table[table.index.notnull()]
                return table
             
                 
@@ -403,7 +404,7 @@ class Database():
                 # load table from database
                 
                     filePath = self._getTableFilePath(ID)
-                    table = read_csv(filePath,load_raw).drop_duplicates()
+                    table = read_csv(filePath,native_regions).drop_duplicates()
                     table = table[table.index.notnull()]
                     return table
             except Exception:
@@ -414,30 +415,44 @@ class Database():
         
         raise(BaseException('Table {} not found'.format(ID)))
         
-    def getTables(self, iterIDs):
+    def getTables(self, iterIDs, native_regions=False, disable_progress=None):
         """
         Method to return multiple datatables at once as a dictionary like 
         set fo tables.
         
         Input 
         -----
-        table list : list [str]
-        
+        iterIDS: list [str]
+            List of IDs to load.
+        native_regions : bool, optional
+            Load native region defintions if available. The default is False.
+        disable_progress : bool, optional
+            Disable displaying of progressbar. The default None hides the
+            progressbar on non-tty outputs
+
         Returns
+        -------
         tables : TableSet
         """
         
         if config.logTables:
             IDs = list()
         res = TableSet()
-        for ID in tqdm.tqdm(iterIDs):
-            table = self.getTable(ID)
+        for ID in tqdm.tqdm(iterIDs, disable=disable_progress):
+            table = self.getTable(ID,native_regions)
             if config.logTables:
                 IDs.append(ID)
             res.add(table)
         if config.logTables:
             core.LOG['tableIDs'].extend(IDs)
         return res
+    
+    def getTablesAvailable(self):
+        """
+        Return a locally stored pandas dataframe of tables
+        on datashelf
+        """
+        return pd.read_csv(os.path.join(config.PATH_TO_DATASHELF, 'datashelf_contents.csv'))
   
     def startLogTables(self):
         """
@@ -580,10 +595,12 @@ class Database():
         
         else:
             for dataTable in tqdm.tqdm(dataTables):
+                
+            
                 if config.DEBUG:
                     print(dataTable.ID)
-                # if cleanTables:
-                #    dataTable = util.cleanDataTable(dataTable)
+                if cleanTables:
+                    dataTable = util.cleanDataTable(dataTable)
                 
                 if dataTable.isnull().all().all():
                     print('ommiting empty table: ' + dataTable.ID)
@@ -666,6 +683,8 @@ class Database():
         message        : str 
                          Commit message to describle the added data
         """ 
+        
+        
         sourcesToUpdate = list()
         for tableID in oldTableIDs:
             sourceID = self._getSourceFromID(tableID)
@@ -678,7 +697,7 @@ class Database():
                 raise(BaseException('source  does not exist'))
         
         # loop over tables
-        for oldTableID, newDataTable in tqdm.tqdm(zip(oldTableIDs, newDataTables)):
+        for oldTableID, newDataTable in tqdm.tqdm(zip(oldTableIDs, newDataTables), desc= 'Updating tables'):
             
             if oldTableID in self.inventory.index:
                 self._updateTable(oldTableID, newDataTable)
@@ -716,6 +735,47 @@ class Database():
         self.add_to_inventory(newDataTable)
 
 
+    def updateTablesAvailable(self,private_access_token):
+        """
+        Method to update module data folder with the latest 
+        datashelf contents on Gitlab
+
+        Requirements:
+        
+            - private_access_token: generated on Gitlab
+
+        """
+
+        try:
+            import gitlab
+        except ImportError:
+            print('python-gitlab not available: Install with mamba or conda')
+            raise
+
+        gl = gitlab.Gitlab(private_token=private_access_token)
+        # define group 
+        group = gl.groups.get("climateanalytics/datashelf")
+        projects = group.projects.list(include_subgroups=True, all=True)
+        print('fetching datashelf contents...')
+        # init list
+        rows = []
+        for project in projects:
+            # append
+            rows.append({'table'          : project.name, 
+                         'last_update'    : pd.to_datetime(project.last_activity_at),
+                         'description'    : project.description,
+                         #'fetched'        : pd.to_datetime('today')
+                         })
+        # make df
+        tables = pd.DataFrame(rows)
+        # change datetime
+        tables['last_update'] = tables['last_update'].dt.strftime('%d-%m-%Y')
+        #tables['fetched']     = tables['fetched'].dt.strftime('%d-%m-%Y')
+        # overwrite table in module data
+        tables.to_csv(os.path.join(config.PATH_TO_DATASHELF, 'datashelf_contents.csv'),index=False)
+        print('done')
+
+
     def validate_ID(self, ID, print_statement=True):
         """ 
         Method to chekc the validity of a table ID and check the state of the 
@@ -781,7 +841,7 @@ class Database():
             if not self.isSource(sourceID):
                 raise(BaseException('source  does not exist'))
         
-        for ID in IDList:
+        for ID in tqdm.tqdm(IDList,desc="Removing tables"):
             source = self.inventory.loc[ID, 'source']
             tablePath = self._getTableFilePath(ID)
 
@@ -1030,7 +1090,8 @@ class Database():
     
     def query_to_long_table(self, 
                             query, 
-                            meta_list = ['variable', 'region','scenario', 'model', 'unit']):
+                            native_regions=False,
+                            meta_list = ['variable', 'region','scenario', 'model', 'source', 'unit']):
     
     
         tables = [self.getTable(x) for x in query.index]
@@ -1038,6 +1099,12 @@ class Database():
         for table in tables:
             if table.empty:
                 continue
+            
+            if native_regions:
+                table = table.reset_index('standard_region',drop=True)
+            else:
+                table = table.reset_index('region',drop=True)
+                
             inp_dict = dict()    
             for metaKey in meta_list:
                 if metaKey == 'region':
@@ -1061,7 +1128,9 @@ class GitRepository_Manager:
     """
     # Management of git repositories for fast access
     """
-    def __init__(self, config):
+    def __init__(self, 
+                 config,
+                 debugmode = False):
         self.PATH_TO_DATASHELF = config.PATH_TO_DATASHELF
         self.sources = pd.read_csv(config.SOURCE_FILE, index_col='SOURCE_ID')
         
@@ -1069,14 +1138,17 @@ class GitRepository_Manager:
         self.updatedRepos = set()
         self.validatedRepos = set()
         self.filesToAdd   = defaultdict(list)
-
-        for sourceID in self.sources.index:
-            repoPath = os.path.join(self.PATH_TO_DATASHELF,  'database', sourceID)
-            self.repositories[sourceID] = git.Repo(repoPath)
-            self.verifyGitHash(sourceID)
         
-        self.repositories['main'] = git.Repo(self.PATH_TO_DATASHELF)
-        self._validateRepository('main')
+        if not debugmode:
+            for sourceID in self.sources.index:
+                repoPath = os.path.join(self.PATH_TO_DATASHELF,  'database', sourceID)
+                self.repositories[sourceID] = git.Repo(repoPath)
+                self.verifyGitHash(sourceID)
+            
+            self.repositories['main'] = git.Repo(self.PATH_TO_DATASHELF)
+            self._validateRepository('main')
+        else:
+            print('Git manager initialized in debugmode')
 
     def __getitem__(self, sourceID):
         """ 
@@ -1139,6 +1211,7 @@ class GitRepository_Manager:
 
         self.commit('added source: ' + repoID)
 
+
     def gitAddFile(self, repoName, filePath):
         """
         Addes a new file to a repository
@@ -1165,7 +1238,6 @@ class GitRepository_Manager:
         """
         if config.DEBUG:
             print('Removed file {} to repo: {}'.format(filePath,repoName))
-#        self[repoName].index.remove(filePath, working_tree=True)
         self[repoName].git.execute(["git", "rm", "-f", filePath]) #TODO Only works with -f forced, but why?
         self.updatedRepos.add(repoName)
     
