@@ -461,6 +461,278 @@ class CD_LINKS(object):
         
         mapping = pd.DataFrame(mapping.items(), columns = ['native', 'standard'])
         return mapping.set_index(org).to_dict()[dest]
+
+class IPCC_AR6(object):
+    
+    def region_mapping(self, 
+                        org = 'native', 
+                        dest='standard'):
+        
+        mapping = {'World': 'World',
+         'Sao Tome and Principe': 'STP',
+         'Turkmenistan': 'TKM',
+         'Saint Helena': 'SHN',
+         'Lithuania': 'LTU',
+         'Cambodia': 'KHM',
+         'Ethiopia': 'ETH',
+         'Aruba': 'ABW',
+         'Swaziland': None,
+         'Palestine': None,
+         'Bolivia': 'BOL',
+         'Bahamas, The': None,
+         'Burkina Faso': 'BFA',
+         'Ghana': 'GHA',
+         'Cape Verde': None,
+         'Slovenia': 'SVN',
+         'Guatemala': 'GTM',
+         'Bosnia and Herzegovina': 'BIH',
+         'Guinea': 'GIN',
+         'Jordan': 'JOR',
+         'Congo, Rep.': None,
+         'Spain': 'ESP',
+         'Liberia': 'LBR',
+         'Netherlands': 'NLD',
+         'Jamaica': 'JAM',
+         'Oman': 'OMN',
+         'Tanzania': None,
+         'Albania': 'ALB',
+         'Gabon': 'GAB',
+         'Niue': 'NIU',
+         'New Zealand': 'NZL',
+         'Yemen': 'YEM',
+         'Pakistan': 'PAK',
+         'Greenland': 'GRL',
+         'Samoa': 'WSM',
+         'Slovak Republic': None,
+         'United Arab Emirates': 'ARE',
+         'Guam': 'GUM',
+         'Kosovo': None,
+         'Azerbaijan': 'AZE',
+         'Madagascar': 'MDG',
+         'Lesotho': 'LSO',
+         'Saint Vincent and the Grenadines': None,
+         'Kenya': 'KEN',
+         'South Korea': None,
+         'Belarus': 'BLR',
+         'Tajikistan': 'TJK',
+         'Afghanistan': 'AFG',
+         'Bangladesh': 'BGD',
+         'Mauritania': 'MRT',
+         'Solomon Islands': 'SLB',
+         'Turks and Caicos Islands': 'TCA',
+         'Saint Lucia': 'LCA',
+         'Cyprus': 'CYP',
+         'French Polynesia': 'PYF',
+         'France': 'FRA',
+         'Bermuda': 'BMU',
+         'Namibia': 'NAM',
+         'Somalia': 'SOM',
+         'Peru': 'PER',
+         'Laos': None,
+         'Nauru': 'NRU',
+         'Seychelles': 'SYC',
+         'Norway': 'NOR',
+         "Cote d'Ivoire": None,
+         'Cook Islands': 'COK',
+         'Benin': 'BEN',
+         'Western Sahara': 'ESH',
+         'Cuba': 'CUB',
+         'Cameroon': 'CMR',
+         'Montenegro': 'MNE',
+         'Saint Kitts and Nevis': 'KNA',
+         'Togo': 'TGO',
+         'Armenia': 'ARM',
+         'Antigua and Barbuda': 'ATG',
+         'Dominican Republic': 'DOM',
+         'Ukraine': 'UKR',
+         'Bahrain': 'BHR',
+         'Tonga': 'TON',
+         'Finland': 'FIN',
+         'Libya': 'LBY',
+         'Central African Republic': 'CAF',
+         'Sweden': 'SWE',
+         'British Virgin Islands': 'VGB',
+         'Mali': 'MLI',
+         'Bulgaria': 'BGR',
+         'Mauritius': 'MUS',
+         'Romania': 'ROU',
+         'Angola': 'AGO',
+         'Portugal': 'PRT',
+         'South Africa': 'ZAF',
+         'Fiji': 'FJI',
+         'Brunei Darussalam': 'BRN',
+         'Malaysia': 'MYS',
+         'Austria': 'AUT',
+         'Mozambique': 'MOZ',
+         'Uganda': 'UGA',
+         'Kyrgyz Republic': None,
+         'Hungary': 'HUN',
+         'Niger': 'NER',
+         'Falkland Islands': None,
+         'Kuwait': 'KWT',
+         'Panama': 'PAN',
+         'Guyana': 'GUY',
+         'Costa Rica': 'CRI',
+         'Luxembourg': 'LUX',
+         'American Samoa': 'ASM',
+         'Gibraltar': 'GIB',
+         'Ireland': 'IRL',
+         'Nigeria': 'NGA',
+         'Ecuador': 'ECU',
+         'Czech Republic': 'CZE',
+         'Iran': None,
+         'Algeria': 'DZA',
+         'El Salvador': 'SLV',
+         'Saint Pierre and Miquelon': 'SPM',
+         'Chile': 'CHL',
+         'Puerto Rico': 'PRI',
+         'Belgium': 'BEL',
+         'Haiti': 'HTI',
+         'Iraq': 'IRQ',
+         'Sierra Leone': 'SLE',
+         'Georgia': 'GEO',
+         'Hong Kong (China)': None,
+         'Denmark': 'DNK',
+         'Poland': 'POL',
+         'Moldova': None,
+         'Morocco': 'MAR',
+         'Croatia': 'HRV',
+         'Mongolia': 'MNG',
+         'Guinea-Bissau': 'GNB',
+         'Kiribati': 'KIR',
+         'Switzerland': 'CHE',
+         'Grenada': 'GRD',
+         'Belize': 'BLZ',
+         'Chad': 'TCD',
+         'Estonia': 'EST',
+         'Uruguay': 'URY',
+         'Equatorial Guinea': 'GNQ',
+         'Lebanon': 'LBN',
+         'Uzbekistan': 'UZB',
+         'Tunisia': 'TUN',
+         'Djibouti': 'DJI',
+         'Rwanda': 'RWA',
+         'Timor-Leste': 'TLS',
+         'Dominica': 'DMA',
+         'Colombia': 'COL',
+         'Reunion': None,
+         'Burundi': 'BDI',
+         'Taiwan': None,
+         'Nicaragua': 'NIC',
+         'Barbados': 'BRB',
+         'Qatar': 'QAT',
+         'Congo, Dem. Rep.': None,
+         'Italy': 'ITA',
+         'Bhutan': 'BTN',
+         'Sudan': 'SDN',
+         'Nepal': 'NPL',
+         'Malta': 'MLT',
+         'Maldives': 'MDV',
+         'Suriname': 'SUR',
+         'Cayman Islands': 'CYM',
+         'Venezuela': 'VEN',
+         'Israel': 'ISR',
+         'Iceland': 'ISL',
+         'Zambia': 'ZMB',
+         'Senegal': 'SEN',
+         'Papua New Guinea': 'PNG',
+         'Malawi': 'MWI',
+         'Macau (China)': None,
+         'Trinidad and Tobago': 'TTO',
+         'Zimbabwe': 'ZWE',
+         'Germany': 'DEU',
+         'Vanuatu': 'VUT',
+         'Martinique': 'MTQ',
+         'Kazakhstan': 'KAZ',
+         'Philippines': 'PHL',
+         'Eritrea': 'ERI',
+         'Montserrat': 'MSR',
+         'New Caledonia': 'NCL',
+         'Macedonia': None,
+         'North Korea': None,
+         'Paraguay': 'PRY',
+         'Latvia': 'LVA',
+         'Syria': None,
+         'Honduras': 'HND',
+         'Myanmar': 'MMR',
+         'Egypt': 'EGY',
+         'Singapore': 'SGP',
+         'Serbia': 'SRB',
+         'Botswana': 'BWA',
+         'United Kingdom': 'GBR',
+         'Antarctica': 'ATA',
+         'Gambia, The': None,
+         'Greece': 'GRC',
+         'Sri Lanka': 'LKA',
+         'French Guiana': 'GUF',
+         'Comoros': 'COM',
+         'Micronesia (Federated States of)': 'FSM',
+         'Guadeloupe': 'GLP',
+         'Mayotte': 'MYT',
+         'South Sudan': 'SSD',
+         'Virgin Islands (U.S.)': None,
+         'Curaçao': 'CUW',
+         'OECD90 and EU (and EU candidate) countries (R6)': None,
+         'Countries from the Reforming Ecomonies of the Former Soviet Union (R6)': None,
+         'Asian countries except Japan (R6)': None,
+         'Countries of the Middle East (R6)': None,
+         'Countries of Sub-Saharan Africa (R6)': None,
+         'Latin American countries (R6)': None,
+         'Rest of the World (R6)': None,
+         'OECD90 and EU (and EU candidate) countries': 'R5OECD',
+         'Countries from the Reforming Ecomonies of the Former Soviet Union': 'R5REF',
+         'Asian countries except Japan': 'R5ASIA',
+         'Countries of the Middle East and Africa': 'R5MAF',
+         'Latin American countries': 'R5LAM',
+         'Rest of the World (R5)': 'R5ROWO',
+         'North America; primarily the United States of America and Canada': None,
+         'Eastern and Western Europe (i.e., the EU28)': None,
+         'Pacific OECD': None,
+         'Reforming Economies of Eastern Europe and the Former Soviet Union; primarily Russia': None,
+         'Countries of centrally-planned Asia; primarily China': None,
+         'Countries of South Asia; primarily India': None,
+         'Other countries of Asia': None,
+         'Countries of Sub-Saharan Africa': None,
+         'Countries of the Middle East; Iran, Iraq, Israel, Saudi Arabia, Qatar, etc.': None,
+         'Countries of Latin America and the Caribbean': None,
+         'Rest of the World (R10)': None,
+         'Argentina': 'ARG',
+         'Australia': 'AUS',
+         'Brazil': 'BRA',
+         'Canada': 'CAN',
+         'China': 'CHN',
+         'European Union (28 member countries)': 'EU28',
+         'India': 'IND',
+         'Indonesia': 'IDN',
+         'Japan': 'JPN',
+         'Mexico': 'MEX',
+         'Russia': 'RUS',
+         'Saudi Arabia': 'SAU',
+         'Thailand': 'THA',
+         'Turkey': 'TUR',
+         'United States of America': 'USA',
+         'Vietnam\xa0': None,
+        'R5ASIA' : 'R5ASIA', 
+        'R5LAM' : 'R5LAM', 
+        'R5MAF' : 'R5MAF', 
+        'R5OECD90+EU' : 'R5OECD', 
+        'R5REF' : 'R5REF',
+        'R5ROWO' : 'R5ROWO',
+        'R10AFRICA': 'R10AFRICA',
+         'R10CHINA+': 'R10CHINA+',
+         'R10EUROPE': 'R10EUROPE',
+         'R10INDIA+': 'R10INDIA+',
+         'R10LATIN_AM': 'R10LATIN_AM',
+         'R10MIDDLE_EAST': 'R10MIDDLE_EAST',
+         'R10NORTH_AM': 'R10NORTH_AM',
+         'R10PAC_OECD': 'R10PAC_OECD',
+         'R10REF_ECON': 'R10REF_ECON',
+         'R10REST_ASIA': 'R10REST_ASIA'}
+        
+        
+        mapping = pd.DataFrame(mapping.items(), columns = ['native', 'standard'])
+        return mapping.set_index(org).to_dict()[dest]
+
 class IPCC_AR5(object):
     
     def region_mapping(self, 
